/*
 * Copyright 2017 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.diirt.datasource.internal;

import org.diirt.vtype.VByte;

import com.aquenos.epics.jackie.common.value.ChannelAccessControlsChar;
import com.aquenos.epics.jackie.common.value.ChannelAccessTimeChar;
import com.aquenos.epics.jackie.common.value.ChannelAccessValueType;
import com.aquenos.epics.jackie.diirt.vtype.JackieVByte;

/**
 * Type adapter that convert from {@link ChannelAccessControlsChar} and
 * {@link ChannelAccessTimeChar} to {@link VByte}. This adapter can only be used
 * if the value has exactly one element.
 * 
 * @author Sebastian Marsching
 */
public class ScalarCharTypeAdapter extends JackieDataSourceTypeAdapter<VByte> {

    /**
     * Single instance of this adapter.
     */
    public static final ScalarCharTypeAdapter INSTANCE = new ScalarCharTypeAdapter();

    private ScalarCharTypeAdapter() {
        super(true, ChannelAccessValueType.DBR_CHAR, VByte.class);
    }

    @Override
    protected VByte convertValue(JackieConnectionPayload connection,
            JackieMessagePayload message) {
        // We can safely make a cast here because this adapter is only used if
        // the channel's native type is DBR_CHAR and we thus know that the
        // monitors return a DBR_CTRL_CHAR and DBR_TIME_CHAR.
        ChannelAccessControlsChar controlsValue = (ChannelAccessControlsChar) message
                .getControlsValue();
        ChannelAccessTimeChar timeValue = (ChannelAccessTimeChar) message
                .getTimeValue();
        return new JackieVByte(controlsValue, timeValue,
                connection.getDisconnectTime());
    }

}
