/*
 * Copyright 2017 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.diirt.datasource.internal;

import org.diirt.vtype.VEnum;

import com.aquenos.epics.jackie.common.value.ChannelAccessGraphicsEnum;
import com.aquenos.epics.jackie.common.value.ChannelAccessTimeEnum;
import com.aquenos.epics.jackie.common.value.ChannelAccessValueType;
import com.aquenos.epics.jackie.diirt.vtype.JackieVEnum;

/**
 * Type adapter that convert from {@link ChannelAccessGraphicsEnum} and
 * {@link ChannelAccessTimeEnum} to {@link VEnum}. This adapter can only be used
 * if the value has exactly one element.
 * 
 * @author Sebastian Marsching
 */
public class ScalarEnumTypeAdapter extends JackieDataSourceTypeAdapter<VEnum> {

    /**
     * Single instance of this adapter.
     */
    public static final ScalarEnumTypeAdapter INSTANCE = new ScalarEnumTypeAdapter();

    private ScalarEnumTypeAdapter() {
        super(true, ChannelAccessValueType.DBR_ENUM, VEnum.class);
    }

    @Override
    protected VEnum convertValue(JackieConnectionPayload connection,
            JackieMessagePayload message) {
        // We can safely make a cast here because this adapter is only used if
        // the channel's native type is DBR_SHORT and we thus know that the
        // monitors return a DBR_CTRL_SHORT and DBR_TIME_SHORT.
        ChannelAccessGraphicsEnum graphicsValue = (ChannelAccessGraphicsEnum) message
                .getControlsValue();
        ChannelAccessTimeEnum timeValue = (ChannelAccessTimeEnum) message
                .getTimeValue();
        return new JackieVEnum(graphicsValue, timeValue,
                connection.getDisconnectTime());
    }

}
