/*
 * Copyright 2017 aquenos GmbH.
 * All rights reserved.
 * 
 * Please refer to the file NOTICE.txt in the root of the source distribution or
 * in the META-INF directory of the binary archive for licensing information.
 */

package com.aquenos.epics.jackie.diirt.vtype;

import java.time.Instant;

import org.diirt.vtype.VByte;
import org.diirt.vtype.VTypeToString;

import com.aquenos.epics.jackie.common.value.ChannelAccessControlsChar;
import com.aquenos.epics.jackie.common.value.ChannelAccessTimeChar;

/**
 * {@link VByte} implementation that is backed by a
 * {@link ChannelAccessControlsChar} and {@link ChannelAccessTimeChar}.
 * 
 * @author Sebastian Marsching
 */
public final class JackieVByte
        extends JackieDisplay<ChannelAccessControlsChar, ChannelAccessTimeChar>
        implements VByte {

    /**
     * <p>
     * Creates a value backed by the specified {@code controlsValue} and
     * {@code timeValue}. The {@code controlsValue} is used for the meta-data
     * (engineering units, limits, etc.) and the {@code timeValue} is used for
     * the alarm status, time-stamp, and value. The {@code timeValue} must have
     * exactly one element.
     * </p>
     * 
     * <p>
     * If {@code disconnectTime} is not <code>null</code>, it is used as the
     * time-stamp and the alarm severity is set to {@code UNDEFINED}.
     * </p>
     * 
     * @param controlsValue
     *            value used for meta-data (engineering units, limits, etc.).
     * @param timeValue
     *            value used for alarm status, time-stamp, and value. It must
     *            have exactly one element.
     * @param disconnectTime
     *            time at which the channel was disconnected. Usually this
     *            should be <code>null</code>. If it is not <code>null</code>,
     *            the alarm severity is set to {@code UNDEFINED} and this
     *            parameter is used as the time-stamp (instead of using the
     *            time-stamp from the {@code timeValue}.
     * @throws IllegalArgumentException
     *             if {@code timeValue} has more or less than one element.
     */
    public JackieVByte(ChannelAccessControlsChar controlsValue,
            ChannelAccessTimeChar timeValue, Instant disconnectTime) {
        super(controlsValue, timeValue, disconnectTime, true, true);
    }

    @Override
    public Byte getValue() {
        return timeValue.getValue().get(0);
    }

    @Override
    public String toString() {
        return VTypeToString.toString(this);
    }

}
